import React from 'react';
import ReactDOM from 'react-dom';

import BookingForm from './BookingForm';
import BookingHistory from './BookingHistory';


class BookingWindow extends React.Component {
  constructor(props) {
    super(props);

    // Set start date (tomorrow).
    var startDate = new Date();
    startDate.setDate(startDate.getDate() + 1);
    // Set end date (tomorrow + 1h).
    var endDate = new Date();
    endDate.setDate(endDate.getDate() + 1);
    endDate.setHours(endDate.getHours() + 1);

    this.state = {
      startDate: startDate,
      endDate: endDate,
      buttonDisabled: true,
      statusMessage: Drupal.t('Select the period to check the availability'),
      statusClass: 'alert alert-secondary',
      bookingHostory: [],
    };
    this.handleStartChange = this.handleStartChange.bind(this);
    this.handleEndChange = this.handleEndChange.bind(this);
    this.handleSubmit = this.handleSubmit.bind(this);
  }

  componentDidMount() {
    this.getBookingHistory();
  }

  handleStartChange(date) {
    // Make sure endDate is to before startDate,
    if (date >= this.state.endDate) {
      let endDate = date;
      endDate.setHours(endDate.getHours() + 1);
      this.setState({
        endDate: endDate
      });
    }

    this.setState({
      startDate: date
    });
    this.checkAvailabilty(date, this.state.endDate);
  };

  handleEndChange(date) {
    // Make sure endDate is to before startDate,
    if (date < this.state.startDate) {
      date = this.state.startDate;
    }

    this.setState({
      endDate: date
    });
    this.checkAvailabilty(this.state.startDate, date);
  };

  checkAvailabilty(startDate, endDate) {
    this.setState({
      statusMessage: Drupal.t('Looking up for availability...')
    });

    nextpath_client.checkAvailability(this.props.dataUnitId, this.props.dataEventType, nextpath_helpers.formatDate(startDate), nextpath_helpers.formatDate(endDate), (bookings) => (
      this.setState({
        buttonDisabled: bookings.data.length > 0 ? true : false,
        statusMessage: bookings.data.length > 0 ? Drupal.t('Unit already booked in the selected period') : Drupal.t('Unit available for booking'),
        statusClass: bookings.data.length > 0 ? 'alert alert-warning' : 'alert alert-primary'
      })
    ));
  }

  handleSubmit() {
    const b = nextpath_helpers.createBooking(this.props.dataUnitId, this.props.dataEventType, this.props.dataEventState, nextpath_helpers.formatDate(this.state.startDate), nextpath_helpers.formatDate(this.state.endDate), null);
    nextpath_client.createBooking(b, this.props.dataEventType, (reply) => (
      this.checkSubmitResult(reply)
    ));
  };

  checkSubmitResult(reply) {
    if(reply.hasOwnProperty('data') && reply.data.hasOwnProperty('id') ){
      this.getBookingHistory();
      this.setState({
        buttonDisabled: true,
        statusMessage: Drupal.t('Booking was successful'),
        statusClass: 'alert alert-success',
      })
    }
    else {
      this.setState({
        buttonDisabled: false,
        statusMessage: Drupal.t('An error occured while booking the unit, please try again later'),
        statusClass: 'alert alert-danger',
      })
    }
  }

  getBookingHistory() {
    nextpath_client.getBookingHistory(this.props.dataUnitId, this.props.dataEventType, (bookings) => (
      this.setState({
        bookingHostory: bookings.data,
      })
    ));
  }

  render() {
    return (
      <div className="booking-window row">
        <div className="col-sm-8">
          <BookingForm
            startDate={this.state.startDate}
            endDate={this.state.endDate}
            handleStartChange={this.handleStartChange}
            handleEndChange={this.handleEndChange}
            onFormSubmit={this.handleSubmit}
            buttonDisabled={this.state.buttonDisabled}
            statusClass={this.state.statusClass}
            statusMessage={this.state.statusMessage}
          />
        </div>
        <div className="col-sm-4">
          <BookingHistory
            bookingHostory={this.state.bookingHostory}
            dataUnitId={this.props.dataUnitId}
          />
        </div>
      </div>
    );
  }
}

export default BookingWindow;
